@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 import testtools
 
 from neutron_fwaas.privileged import utils
@@ -39,27 +40,14 @@ class InNamespaceTest(base.BaseTestCase):
         self.addCleanup(close_patch.stop)
 
         self.setns_mock = mock.patch(
-            'pyroute2.netns.setns', side_effect=self.fake_setns
-        ).start()
-
-    def fake_setns(self, setns):
-        if setns is self.ORG_NETNS_FD:
-            return self.ORG_NETNS_FD
-        elif setns is self.NEW_NETNS:
-            return self.NEW_NETNS_FD
-        else:
-            self.fail('invalid netns name')
+            'pyroute2.netns.setns').start()
 
     def test_in_namespace(self):
         with utils.in_namespace(self.NEW_NETNS):
             self.setns_mock.assert_called_once_with(self.NEW_NETNS)
 
-        setns_calls = [mock.call(self.NEW_NETNS),
-                       mock.call(self.ORG_NETNS_FD)]
-        close_calls = [mock.call(self.NEW_NETNS_FD),
-                       mock.call(self.ORG_NETNS_FD)]
+        setns_calls = [mock.call(self.NEW_NETNS), mock.call(self.ORG_NETNS_FD)]
         self.setns_mock.assert_has_calls(setns_calls)
-        self.close_mock.assert_has_calls(close_calls)
 
     def test_in_no_namespace(self):
         for namespace in ('', None):
@@ -74,12 +62,8 @@ class InNamespaceTest(base.BaseTestCase):
                 self.setns_mock.assert_called_once_with(self.NEW_NETNS)
                 raise ValueError
 
-        setns_calls = [mock.call(self.NEW_NETNS),
-                       mock.call(self.ORG_NETNS_FD)]
-        close_calls = [mock.call(self.NEW_NETNS_FD),
-                       mock.call(self.ORG_NETNS_FD)]
+        setns_calls = [mock.call(self.NEW_NETNS), mock.call(self.ORG_NETNS_FD)]
         self.setns_mock.assert_has_calls(setns_calls)
-        self.close_mock.assert_has_calls(close_calls)
 
     def test_in_namespace_enter_failed(self):
         self.setns_mock.side_effect = ValueError
@@ -88,7 +72,6 @@ class InNamespaceTest(base.BaseTestCase):
                 self.fail('It should fail before we reach this code')
 
         self.setns_mock.assert_called_once_with(self.NEW_NETNS)
-        self.close_mock.assert_called_once_with(self.ORG_NETNS_FD)
 
     def test_in_namespace_exit_failed(self):
         self.setns_mock.side_effect = [self.NEW_NETNS_FD, ValueError]
