@@ -12,7 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from neutron_lib import constants
 from neutron_lib.plugins.ml2 import ovs_constants as ovs_consts
 import testtools
