@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from neutron.agent.l3 import l3_agent_extension_api as l3_agent_api
 from neutron.agent.l3 import router_info
 from neutron.agent.linux import ip_lib
@@ -66,9 +67,6 @@ def _setup_test_agent_class(service_plugins):
         def delete_router(self, context, data):
             pass
 
-        def update_router(self, context, data):
-            pass
-
     return FWaasTestAgent
 
 
@@ -253,11 +251,16 @@ class TestFWaaSL3AgentExtension(base.BaseTestCase):
                           'ports': [],
                           'add-port-ids': [],
                           'del-port-ids': [],
-                          'router_ids': []}
+                          'last-port': True}
 
         self.api.plugin_rpc = mock.Mock()
-        with mock.patch.object(self.api.fwaas_driver, 'update_firewall_group'
-                               ) as mock_driver_update_firewall_group, \
+        with mock.patch.object(self.api, '_get_firewall_group_ports'
+                               ) as mock_get_firewall_group_ports, \
+                mock.patch.object(self.api, '_get_in_ns_ports'
+                                  ) as mock_get_in_ns_ports, \
+                mock.patch.object(self.api.fwaas_driver,
+                                  'update_firewall_group'
+                                  ) as mock_driver_update_firewall_group, \
                 mock.patch.object(self.api.fwplugin_rpc,
                                   'set_firewall_group_status'
                                   ) as mock_set_firewall_group_status:
@@ -266,6 +269,15 @@ class TestFWaaSL3AgentExtension(base.BaseTestCase):
 
             self.api.update_firewall_group(self.context, firewall_group,
                     host='host')
+            calls = [
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group, require_new_plugin=True,
+                    to_delete=True),
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group)
+            ]
+            mock_get_firewall_group_ports.assert_has_calls(calls)
+            mock_get_in_ns_ports.assert_called
             mock_set_firewall_group_status.assert_called_once_with(
                     self.context, firewall_group['id'], 'INACTIVE')
 
@@ -278,8 +290,32 @@ class TestFWaaSL3AgentExtension(base.BaseTestCase):
                           'del-port-ids': [],
                           'last-port': False
                           }
-        self.api.update_firewall_group(self.context, firewall_group,
-                                       host='host')
+        with mock.patch.object(self.api, '_get_firewall_group_ports'
+                               ) as mock_get_firewall_group_ports, \
+                mock.patch.object(self.api, '_get_in_ns_ports'
+                                  ) as mock_get_in_ns_ports, \
+                mock.patch.object(self.api.fwaas_driver,
+                                  'update_firewall_group'
+                                  ) as mock_driver_update_firewall_group, \
+                mock.patch.object(self.api.fwplugin_rpc,
+                                  'set_firewall_group_status'
+                                  ) as mock_set_firewall_group_status:
+
+            mock_driver_update_firewall_group.return_value = True
+
+            self.api.update_firewall_group(self.context, firewall_group,
+                    host='host')
+            calls = [
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group, require_new_plugin=True,
+                    to_delete=True),
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group)
+            ]
+            mock_get_firewall_group_ports.assert_has_calls(calls)
+            mock_get_in_ns_ports.assert_called
+            mock_set_firewall_group_status.assert_called_once_with(
+                    self.context, firewall_group['id'], 'ACTIVE')
 
     def test_update_firewall_group_with_only_ports_removed(self):
         firewall_group = {'id': 0, 'project_id': 1,
@@ -290,15 +326,67 @@ class TestFWaaSL3AgentExtension(base.BaseTestCase):
                           'last-port': False
                           }
         self.api.plugin_rpc = mock.Mock()
-        with mock.patch.object(self.api.fwaas_driver, 'update_firewall_group'
-                               ) as mock_driver_update_firewall_group, \
+        with mock.patch.object(self.api, '_get_firewall_group_ports'
+                               ) as mock_get_firewall_group_ports, \
+                mock.patch.object(self.api, '_get_in_ns_ports'
+                                  ) as mock_get_in_ns_ports, \
+                mock.patch.object(self.api.fwaas_driver,
+                                  'update_firewall_group'
+                                  ) as mock_driver_update_firewall_group, \
                 mock.patch.object(self.api.fwplugin_rpc,
                                   'set_firewall_group_status'
                                   ) as mock_set_firewall_group_status:
 
             mock_driver_update_firewall_group.return_value = True
+
             self.api.update_firewall_group(self.context, firewall_group,
                                            host='host')
+            calls = [
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group, require_new_plugin=True,
+                    to_delete=True),
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group)
+            ]
+            mock_get_firewall_group_ports.assert_has_calls(calls)
+            mock_get_in_ns_ports.assert_called
+            mock_set_firewall_group_status.assert_called_once_with(
+                    self.context, firewall_group['id'], 'ACTIVE')
+
+    def test_update_firewall_group_with_only_policies_added_or_deleted(self):
+        firewall_group = {'id': 0, 'project_id': 1,
+                          'tenant_id': 1,
+                          'admin_state_up': True,
+                          'ports': [1, 2],
+                          'add-port-ids': [],
+                          'del-port-ids': [],
+                          'last-port': False
+                          }
+        self.api.plugin_rpc = mock.Mock()
+        with mock.patch.object(self.api, '_get_firewall_group_ports'
+                               ) as mock_get_firewall_group_ports, \
+                mock.patch.object(self.api, '_get_in_ns_ports'
+                                  ) as mock_get_in_ns_ports, \
+                mock.patch.object(self.api.fwaas_driver,
+                                  'update_firewall_group'
+                                  ) as mock_driver_update_firewall_group, \
+                mock.patch.object(self.api.fwplugin_rpc,
+                                  'set_firewall_group_status'
+                                  ) as mock_set_firewall_group_status:
+
+            mock_driver_update_firewall_group.return_value = True
+
+            self.api.update_firewall_group(self.context, firewall_group,
+                                           host='host')
+            calls = [
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group, require_new_plugin=True,
+                    to_delete=True),
+                mock.call._get_firewall_group_ports(
+                    self.context, firewall_group)
+            ]
+            mock_get_firewall_group_ports.assert_has_calls(calls)
+            mock_get_in_ns_ports.assert_called
             mock_set_firewall_group_status.assert_called_once_with(
                     self.context, firewall_group['id'], 'ACTIVE')
 
@@ -344,7 +432,7 @@ class TestFWaaSL3AgentExtension(base.BaseTestCase):
         ri = self._prepare_router_data()
         ri.internal_ports = ports
         router_info = {ri.router_id: ri}
-        api_object = l3_agent_api.L3AgentExtensionAPI(router_info)
+        api_object = l3_agent_api.L3AgentExtensionAPI(router_info, None)
         self.api.consume_api(api_object)
         fw_port_ids = port_ids
 
@@ -363,7 +451,7 @@ class TestFWaaSL3AgentExtension(base.BaseTestCase):
         ri.internal_ports = ports
         router_info = {}
         router_info[ri.router_id] = ri
-        api_object = l3_agent_api.L3AgentExtensionAPI(router_info)
+        api_object = l3_agent_api.L3AgentExtensionAPI(router_info, None)
         self.api.consume_api(api_object)
         fw_port_ids = port_ids
         ports_for_fw_expected = [(ri, port_ids)]
@@ -475,4 +563,52 @@ class TestFWaaSL3AgentExtension(base.BaseTestCase):
                 mock.call(mock.ANY, {'2'}, fwg2),
             ], mock_invoke_driver.call_args_list)
 
-    #TODO(Margaret) Add test for add_router method.
+    def test_add_router(self):
+        fw_agent = _setup_test_agent_class([fwaas_constants.FIREWALL])
+        cfg.CONF.set_override('enabled', True, 'fwaas')
+        new_router = {
+            '_interfaces': [{
+                'device_owner': 'network: router_interface',
+                'id': '1',
+                'tenant_id': 'demo_tenant_id',
+            }],
+            'tenant_id': 'demo_tenant_id',
+            'id': '0b109a4e-d228-479d-ad43-08bf3245adbb',
+            'name': 'demo_router'
+        }
+        with mock.patch('oslo_utils.importutils.import_object'):
+            agent = fw_agent(cfg.CONF)
+            agent.agent_api = mock.Mock()
+            agent.fwplugin_rpc = mock.Mock()
+            agent.conf.agent_mode = mock.Mock()
+            agent.fwaas_driver = iptables_fwaas_v2.IptablesFwaasDriver()
+            with mock.patch.object(agent,
+                                   '_process_router_update',
+                                   ) as mock_process_router_update:
+                agent.add_router(self.context, new_router)
+                mock_process_router_update.assert_called_with(new_router)
+
+    def test_update_router(self):
+        fw_agent = _setup_test_agent_class([fwaas_constants.FIREWALL])
+        cfg.CONF.set_override('enabled', True, 'fwaas')
+        updated_router = {
+            '_interfaces': [{
+                'device_owner': 'network: router_interface',
+                'id': '1',
+                'tenant_id': 'demo_tenant_id',
+            }],
+            'tenant_id': 'demo_tenant_id',
+            'id': '0b109a4e-d228-479d-ad43-08bf3245adbb',
+            'name': 'demo_router'
+        }
+        with mock.patch('oslo_utils.importutils.import_object'):
+            agent = fw_agent(cfg.CONF)
+            agent.agent_api = mock.Mock()
+            agent.fwplugin_rpc = mock.Mock()
+            agent.conf.agent_mode = mock.Mock()
+            agent.fwaas_driver = iptables_fwaas_v2.IptablesFwaasDriver()
+            with mock.patch.object(agent,
+                                   '_process_router_update',
+                                   ) as mock_process_router_update:
+                agent.update_router(self.context, updated_router)
+                mock_process_router_update.assert_called_with(updated_router)
