@@ -20,6 +20,7 @@ from neutron import extensions as neutron_extensions
 from neutron.tests.unit.extensions import test_l3
 from neutron_lib import constants as nl_constants
 from neutron_lib import context
+from neutron_lib.db import api as db_api
 from neutron_lib.exceptions import firewall_v2 as f_exc
 from neutron_lib.plugins import directory
 from oslo_config import cfg
@@ -39,9 +40,10 @@ DELETEFW_PATH = (FIREWALL_AGENT_PLUGIN + '.FirewallAgentApi.'
 
 
 class FakeAgentApi(agents.FirewallAgentCallbacks):
-    """
-    This class used to mock the AgentAPI delete method inherits from
-    FirewallCallbacks because it needs access to the firewall_deleted method.
+    """This class used to mock the AgentAPI delete method
+
+    It inherits from FirewallCallbacks because it needs access to
+    the firewall_deleted method.
     The delete_firewall method belongs to the FirewallAgentApi, which has
     no access to the firewall_deleted method normally because it's not
     responsible for deleting the firewall from the DB. However, it needs
@@ -163,7 +165,7 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
                 do_delete=False
             ) as fwg:
                 fwg_id = fwg['firewall_group']['id']
-                with ctx.session.begin(subtransactions=True):
+                with db_api.CONTEXT_WRITER.using(ctx):
                     fwg_db = self.db._get_firewall_group(ctx, fwg_id)
                     fwg_db['status'] = nl_constants.PENDING_DELETE
 
@@ -183,7 +185,7 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
         def getdelete(context, fwg_id):
             fwg_db = _get_firewall_group(context, fwg_id)
             # NOTE(cby): Use a different session to simulate a concurrent del
-            with alt_ctx.session.begin(subtransactions=True):
+            with db_api.CONTEXT_READER.using(alt_ctx):
                 alt_ctx.session.query(FirewallGroup).filter_by(
                     id=fwg_id).delete()
             return fwg_db
@@ -197,7 +199,7 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
                 as_admin=True,
             ) as fwg:
                 fwg_id = fwg['firewall_group']['id']
-                with ctx.session.begin(subtransactions=True):
+                with db_api.CONTEXT_WRITER.using(ctx):
                     fwg_db = self.db._get_firewall_group(ctx, fwg_id)
                     fwg_db['status'] = nl_constants.PENDING_DELETE
                     ctx.session.flush()
@@ -240,10 +242,10 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
         with self.firewall_policy(as_admin=True) as fwp:
             fwp_id = fwp['firewall_policy']['id']
             with self.firewall_group(
-                name='test',
-                ingress_firewall_policy_id=fwp_id,
-                egress_firewall_policy_id=fwp_id,
-                admin_state_up=True) as fwg1:
+                    name='test',
+                    ingress_firewall_policy_id=fwp_id,
+                    egress_firewall_policy_id=fwp_id,
+                    admin_state_up=True) as fwg1:
                 self.assertEqual(nl_constants.INACTIVE,
                     fwg1['firewall_group']['status'])
 
@@ -271,10 +273,10 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
             with self.firewall_policy(as_admin=True) as fwp:
                 fwp_id = fwp['firewall_policy']['id']
                 with self.firewall_group(
-                    name='test',
-                    ingress_firewall_policy_id=fwp_id,
-                    egress_firewall_policy_id=fwp_id, ports=fwg_ports,
-                    admin_state_up=True) as fwg1:
+                        name='test',
+                        ingress_firewall_policy_id=fwp_id,
+                        egress_firewall_policy_id=fwp_id, ports=fwg_ports,
+                        admin_state_up=True) as fwg1:
                     self.assertEqual(nl_constants.PENDING_CREATE,
                          fwg1['firewall_group']['status'])
 
@@ -312,11 +314,11 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
                 with self.firewall_policy(as_admin=True) as fwp:
                     fwp_id = fwp['firewall_policy']['id']
                     with self.firewall_group(
-                        name='test',
-                        ingress_firewall_policy_id=fwp_id,
-                        egress_firewall_policy_id=fwp_id,
-                        ports=fwg_ports,
-                        admin_state_up=True) as fwg1:
+                            name='test',
+                            ingress_firewall_policy_id=fwp_id,
+                            egress_firewall_policy_id=fwp_id,
+                            ports=fwg_ports,
+                            admin_state_up=True) as fwg1:
                         self.assertEqual(nl_constants.PENDING_CREATE,
                             fwg1['firewall_group']['status'])
 
@@ -342,10 +344,10 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
             port_id2 = body['port_id']
             fwg_ports = [port_id1, port_id2]
             with self.firewall_group(
-                name='test',
-                default_policy=False,
-                ports=fwg_ports,
-                admin_state_up=True) as fwg1:
+                    name='test',
+                    default_policy=False,
+                    ports=fwg_ports,
+                    admin_state_up=True) as fwg1:
                 self.assertEqual(nl_constants.INACTIVE,
                      fwg1['firewall_group']['status'])
 
@@ -380,10 +382,10 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
 
             fwg_ports = [port_id1, port_id2]
             with self.firewall_group(
-                name='test',
-                default_policy=False,
-                ports=fwg_ports,
-                admin_state_up=True) as fwg1:
+                    name='test',
+                    default_policy=False,
+                    ports=fwg_ports,
+                    admin_state_up=True) as fwg1:
                 self.assertEqual(nl_constants.INACTIVE,
                      fwg1['firewall_group']['status'])
                 data = {'firewall_group': {'ports': [port_id2, port_id3]}}
@@ -432,10 +434,10 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
             with self.firewall_policy(as_admin=True) as fwp:
                 fwp_id = fwp['firewall_policy']['id']
                 with self.firewall_group(
-                    name='test',
-                    ingress_firewall_policy_id=fwp_id,
-                    egress_firewall_policy_id=fwp_id, ports=fwg_ports,
-                    admin_state_up=True) as fwg1:
+                        name='test',
+                        ingress_firewall_policy_id=fwp_id,
+                        egress_firewall_policy_id=fwp_id, ports=fwg_ports,
+                        admin_state_up=True) as fwg1:
                     self.assertEqual(nl_constants.PENDING_CREATE,
                          fwg1['firewall_group']['status'])
                     data = {'firewall_group': {'ports': [port_id2, port_id3]}}
@@ -477,10 +479,10 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
             with self.firewall_policy(as_admin=True) as fwp:
                 fwp_id = fwp['firewall_policy']['id']
                 with self.firewall_group(
-                    name='test',
-                    ingress_firewall_policy_id=fwp_id,
-                    egress_firewall_policy_id=fwp_id, ports=fwg_ports,
-                    admin_state_up=True) as fwg1:
+                        name='test',
+                        ingress_firewall_policy_id=fwp_id,
+                        egress_firewall_policy_id=fwp_id, ports=fwg_ports,
+                        admin_state_up=True) as fwg1:
                     self.assertEqual(nl_constants.PENDING_CREATE,
                          fwg1['firewall_group']['status'])
 
@@ -515,10 +517,10 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
                         as_admin=True) as fwp:
                     fwp_id = fwp['firewall_policy']['id']
                     with self.firewall_group(
-                        name='test',
-                        ingress_firewall_policy_id=fwp_id,
-                        egress_firewall_policy_id=fwp_id, ports=[port_id1],
-                        admin_state_up=True) as fwg1:
+                            name='test',
+                            ingress_firewall_policy_id=fwp_id,
+                            egress_firewall_policy_id=fwp_id, ports=[port_id1],
+                            admin_state_up=True) as fwg1:
                         self.assertEqual(nl_constants.PENDING_CREATE,
                              fwg1['firewall_group']['status'])
 
@@ -548,14 +550,14 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
             port_id1 = body['port_id']
             with self.firewall_rule(as_admin=True) as fwr:
                 with self.firewall_policy(
-                    firewall_rules=[fwr['firewall_rule']['id']],
-                    as_admin=True) as fwp:
+                        firewall_rules=[fwr['firewall_rule']['id']],
+                        as_admin=True) as fwp:
                     fwp_id = fwp['firewall_policy']['id']
                     with self.firewall_group(
-                        name='test',
-                        ingress_firewall_policy_id=fwp_id,
-                        egress_firewall_policy_id=fwp_id, ports=[port_id1],
-                        admin_state_up=True) as fwg1:
+                            name='test',
+                            ingress_firewall_policy_id=fwp_id,
+                            egress_firewall_policy_id=fwp_id, ports=[port_id1],
+                            admin_state_up=True) as fwg1:
                         self.assertEqual(nl_constants.PENDING_CREATE,
                              fwg1['firewall_group']['status'])
 
@@ -596,8 +598,8 @@ class TestAgentDriver(test_fwaas_plugin_v2.FirewallPluginV2TestCase,
     def test_update_firewall_group_with_ports_and_policy(self):
         """neutron firewall_group create test-policy """
         with self.router(name='router1', admin_state_up=True,
-                         tenant_id=self._tenant_id) as r,\
-                self.subnet() as s1,\
+                         tenant_id=self._tenant_id) as r, \
+                self.subnet() as s1, \
                 self.subnet(cidr='20.0.0.0/24') as s2:
 
             body = self._router_interface_action(
